from typing import Any, Dict


def default_log_config(verbose: bool) -> Dict[str, Any]:
    """Setup default config. for dictConfig.
    verbose (bool): set log level: DEBUG if True, INFO if False
    RETURNS (Dict[str, Any])
    """
    log_level = "DEBUG" if verbose else "INFO"
    return {
        "version": 1,
        "disable_existing_loggers": False,
        "handlers": {
            "fastapi_explosion_extras.standard": {
                "level": log_level,
                "class": "logging.StreamHandler",
                "formatter": "fastapi_explosion_extras.standard",
            }
        },
        "formatters": {
            "fastapi_explosion_extras.standard": {
                "format": "%(asctime)s:%(name)s:%(levelname)s %(message)s",
                "datefmt": "%Y-%m-%d %H:%M:%S",
            }
        },
        "loggers": {
            "fastapi_explosion_extras": {
                "handlers": ["fastapi_explosion_extras.standard"],
                "level": log_level,
            }
        },
    }
